#
# spec file for package qjackctl
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# TODO: In wiki stands 1600, but this rise up an error in rpmlint:
# E: invalid-suse-version-check 1600.
%if 0%{?suse_version} > 1550
%define with_qt6 1
%else
%define with_qt6 0
%endif
Name:           qjackctl
Version:        1.0.1
Release:        bp160.1.7
Summary:        Graphical User Interface to Control JACK Servers
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://qjackctl.sourceforge.io/
Source:         https://download.sourceforge.net/qjackctl/qjackctl-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
%if %{with_qt6}
BuildRequires:  cmake(Qt6LinguistTools)
# TODO: Upstream use 6.6
BuildRequires:  pkgconfig(Qt6Core) >= 6.5
BuildRequires:  pkgconfig(Qt6DBus)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(Qt6Xml)
%else
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core) >= 5.2
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(portaudio-2.0)
Requires:       (jack or pipewire-libjack-0_3)
Recommends:     %{name}-lang

%description
JACK Audio Connection Kit - Qt GUI Interface: A simple Qt application
to control the JACK server. Written in C++ around the Qt4 toolkit
for X11, most exclusively using Qt Designer. Provides a simple GUI
dialog for setting several JACK server parameters, which are properly
saved between sessions, and a way control of the status of the audio
server. With time, this primordial interface has become richer by
including a enhanced patchbay and connection control features.

%lang_package

%prep
%setup -q
sed -i '/^X-SuSE-translate/d' src/appdata/org.rncbc.%{name}.desktop

%build
%if %{with_qt6}
%cmake -DCONFIG_QT6=1
%else
%cmake -DCONFIG_QT6=0
%endif
%cmake_build

%install
%cmake_install
%if %{with_qt6}
lrelease6 src/translations/*
%else
lrelease-qt5 src/translations/*
%endif
install -dm 0755 %{buildroot}%{_datadir}/%{name}/translations
install -Dm 0644 src/translations/*.qm %{buildroot}%{_datadir}/%{name}/translations/
install -Dm 0644 src/man1/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%files
%doc ChangeLog README TRANSLATORS
%license LICENSE
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%dir %{_datadir}/icons/hicolor/scalable/apps
%dir %{_datadir}/metainfo
%dir %{_datadir}/%{name}/palette
%{_bindir}/%{name}
%{_datadir}/applications/org.rncbc.%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/org.rncbc.%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/org.rncbc.%{name}.svg
%{_datadir}/metainfo/org.rncbc.%{name}.metainfo.xml
%{_datadir}/%{name}/palette/*.conf
%{_mandir}/man?/%{name}.*

%files lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/%{name}_*.qm
%{_mandir}/fr/man?/%{name}.*

%changelog
* Fri Aug  2 2024 ecsos <ecsos@opensuse.org>
- Update to 1.0.1
  - Graph: thumb-view repositions and resizes immediately when
    visible.
  - Graph: Implement patchbay node search functionality: adds a
    floating text-entry field, which appears when typing in the
    canvas, selecting nodes that contains the typed text
    (maybe regular expression).
  - Graph: fixed a potential use-after-free issue on canvas nodes
    refresh and recycle.
- Changes from 1.0.0
  - Making up the unthinkable (aka. v1.0.0)
  - Cancel button option added to close to system-tray icon message.
  - Graph: Introducing thumbview context-menu.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.13:
  * Graph: Make the main canvas background to mid-gray, when on
    non-dark color themes.
  * Turkish (tr) translation added.
  * Updated copyright headers into the New Year (2024).
* Sat Sep  9 2023 ecsos <ecsos@opensuse.org>
- Update to 0.9.12
  - Setup: disable Settings parameters altogether, except
    frames/period (aka. buffer-size) if running in the so called
    'Active' pure-client mode (eg. under PipeWire's pw-jack
    substitution).
  - Connections: Fixed an old JACK client/ports aliases
    malfunction, hopefully.
  - Graph: Ctrl+left or middle-button click-dragging for panning,
    is now a lot smoother, hopefully.
  - Graph: Click-dragging with the mouse middle-button is now used
    for panning only, not to start a selection anymore.
  - Preppings to next development cycle (Qt >= 6.6)
- Changes from 0.9.11
  - Graph: Soft incremental bounds constraints now imposed to all
    new and old nodes positioning.
  - Prepping into the next development cycle (with Qt >= 6.5).
- Switch Tumbleweed to qt6.
* Fri Mar 24 2023 ecsos <ecsos@opensuse.org>
- Update to 0.9.10
  - Setup: revert to previous settings when dismissing the dialog.
  - Graph: Attempt to make port labels as short as possible.
  - Graph: introducing touch pinch-gesture for zooming.
* Sat Dec 31 2022 ecsos <ecsos@opensuse.org>
- Update to 0.9.9
  - Graph: whether to draw connectors through or around nodes is a
    new user preference option (cf. View > Connect Through Nodes).
  - Graph: Allow middle mouse button for grabbing and dragging the
    main canvas.
  - Make up visual immediate feedback connectlons.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.8:
  * Graph: View / Repel Overlapping Nodes option added.
  * Avoid nagging on D-BUS error messsage windows (or bubbles) when
    trying to start in pure JACK client mode (Active).
  * Add current system user-name to the singleton/unique application
    instance identifier.
  * Graph/Connect and Disconnect keyboard shortcuts added to existing
    [Ins] and [Del], as [Ctrl+C] and [Ctrl+D] respectively; also added
    [F2] as brand new keyboard shortcut for Edit/Rename...
* Sun Apr  3 2022 ecsos <ecsos@opensuse.org>
- Update to 0.9.7
  - Main application icon is now presented in scalable format
    (SVG).
  - Migrated command line parsing to QCommandLineParser/Option
    (Qt >= 5.2)
  - Fixed translations path to be relative to application runtime.
* Mon Jan 10 2022 ecsos <ecsos@opensuse.org>
- Update to 0.9.6
  - Dropped autotools (autoconf, automake, etc.) build system.
  - Limit or mitigate fast auto-scrolling when moving Graph client
    nodes off the viewport.
  - Whenever possible, adopt the previous named default preset,
    when starting the JACK-server on premises.
  - Conditional fix to MacOSX and FreeBSD builds.
* Thu Oct  7 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.5
  - Streamlined Windows and MacOSX deliverables.
  - Korean (ko) translation added.
* Sat Jul 31 2021 Dirk Müller <dmueller@suse.com>
- update to 0.9.4:
  * All builds default to Qt6 (Qt >= 6.1) where available.
  * CMake is now the official build system.
* Fri May 28 2021 Mark Trompell <mark@marktrompell.de>
- Add pipewire-libjack-0_3 as an alternative requirement
* Wed May 12 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.3
  - Graph connection lines drop-shadow eye-candy has been
    optimized, improving a lot on moving highly-connected nodes,
    especially the ones with plenty of backward-curved connections.
  - All packaging builds switching to CMake.
  - Fixed default preset/aliases switching and reloading when
    entering pure-client mode (ie. "Active" status).
* Mon Mar 15 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.2
  - Clock source, Self-connect mode and Server synchronous mode
    options are now always enabled on the Setup / Settings dialog,
    although only available or effective to jackd2.
  - Graph Disconnect now applies to selected connections or nodes
    only.
* Mon Feb  8 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.1
  - Graph Disconnect now applies to all selected ports and
    connections.
  - Main window is now freely resizable, while keeping all the
    buttons stretched to the same aspect ratio.
  - Warning to confirm application close is now back in business
    when functioning as client only (Active).
  - Graph items are automatically raised when created or
    high-lighted (incremental z-value).
  - Add a little but straight horizontal line-gap to the Graph
    connections.
  - Customize the Graph zoom slider widget to reset upon mouse
    middle-button click.
  - Add Clear preset button to Setup dialog.
  - Use default values for most preset parameters: sample rate,
    frames/period (aka. buffer-size), periods/buffer,
    realtime priority, port maximum, client timeout, word length,
    wait time, channel maximum.
  - Early preparations for the New Year develop(ment) cycle.
* Thu Jan 14 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.0
  - List only available backend drivers when JACK D-BUS is enabled.
  - Graph client-name / node-title aliases persistence have been
    hopefully fixed.
  - Get rid of those "JACK has crashed" red-herrings from latest
    Windows(tm) builds.
  - Early fixing to build for Qt >= 6.0.0 and comply with C++17
    standard.
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.3:
  Clock source and Self connect restriction options
  have been added to Setup / Settings / Advanced
  - Added preliminary support for JACK CV signal-type
  ports and JACK OSC event-type ports (Graph only).
  - Left-clicking on the system-tray icon now simply
  toggles the main widget visibility, disregarding
  if already hidden undercover to other windows.
  - Graph nodes and ports are now presented with some
  gradient background.
  - Fixed Setup dialog Cancel (or close) behavior when
  Settings > Parameters > Frames/Period (aka. buffer-
  size) it's the only setting that's changed.
  - Early fixing to build for Qt >= 5.15.0.
  - A scalable (.svg) icon version has been added.
  - Make man page compression reproducible (after request
  by Jelle van der Waa, while on the Vee-Ones, thanks).
  - Ditching deprecated QTime methods for QElapsedTimer's
  (in compliance to Qt >= 5.14.0).
  - Custom color (palette) theme editor introduced; color
  (palette) theme changes are now effective immediately,
  except on default.
  - Second attempt to fix the yet non-official though
  CMake build configuration.
  - When using autotools and ./configure --with-qt=...,
  it is also necessary to adjust the PKG_CONFIG_PATH
  environment variable (after a merge request by plcl
  aka. Pedro López-Cabanillas, while on qmidinet,
  thanks).
  - Graph: avoid self-connecting over their own ports
  when client nodes are selected as a whole group;
  also try to match port-types in a oderly fashion
  when connecting multiple selected ports.
  - Fix HiDPI display screen effective support (Qt >= 5.6).
  - Command line arguments (--start, --preset=[label] and
  - -active-patchbay=[path]) are passed and take effect
  on the current singleton/unique application instance,
  when enabled and already running.
* Sat Apr 13 2019 ecsos@opensuse.org
- Update to 0.5.7
  * Graph node and port title renaming and nodes position move
    changes are now undo/redo-able.
  * Graph client and port title in-place renaming is now integrated
    to native aliases and JACK metadata (aka. pretty-names).
  * Refactored all native client/port name aliases.
  * Re-defined all main application UNIX signal handling.
- Changes from 0.5.6
  * Refactored all singleton/unique application instance setup
    logic away from X11/Xcb hackery.
  * At last, JACK freewheel mode is now being detected as to
    postpone any active patchbay scans as much as possible.
  * Removed old pre-FFADO 'freebob' driver support.
  * HiDPI display screen support (Qt >= 5.6).
  * Graph port temporary highlighting while hovering, if and only
    if connecting ports of same type and complementary modes.
  * Bumped copyright headers into the New Year (2019).
* Sun Nov 25 2018 ecsos@opensuse.org
- Update to 0.5.5
  * Old deprecated Qt4 build support is no more.
  * Graph port sort options added as View / Sort menu.
  * System tray options now subject to current desktop environment
    availability.
  * Also disable Setup / Misc / Other / Save JACK server
    configuration to (.jackdrc) when JACK D-Bus interface is
    enabled.
  * Whether to use server synchronous mode option added to
    Setup / Settings / Parameters (only applied when JACK D-BUS
    interface is enabled).
  * Disable some Setup / Settings / Advanced parameters when
    JACK D-Bus interface is enabled and vice-versa.
  * Attempt to power-cycle JACK D-Bus service on demand;
  * Marked as probably useless anyway, old "H/W Monitor" option
    (-H) is now being ditched from Setup / Settings / Advanced tab.
* Sat Sep 29 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.4
  * Graph port-type colors are now configurable (cf. menu
    View > Colors.
  * Make Graph nodes (ie. client boxes) transparent for yet
    some eye-candiness ;). Also keep the (Graph) current
    selection across port (dis)connections.
  * Drawing patchbay connector lines as (bezier) curves is
    now a difinitive and fixed feature (as long as no more
    remains from the so called "Cambric explosion era" are
    still lurking in there).
  * AppStream metadata updated to be the most compliant with
    latest freedesktop.org specification and recommendation.
  * Graph auto-layout improvement for brand new node clients.
  * Avoid showing setup warning when no server settings have
    changed.
  * Fixed JACK D-Bus settings for MIDI driver parameter.
  version 0.5.3
  * Portuguese (pt) translation added (by Heitor Rocha).
  * AppData/AppStream metadata is now settled under an all
    permisssive license (FSFAP).
  * Improved Graph rubberband add (Shift) and toggle (Ctrl)
    multiple (de)selections.
  * Added user preference option: Setup / Misc / Buttons /
    Replace Connections with Graph button (on main window).
  * Added a zoom slider control to the Graph view status bar.
  version 0.5.2
  * Respect ALSA Sequencer support option also on Graph view.
  * Regression to new Graph node/ports sorting comparator;
    also fixed multiple and many port removals, most probably
    causing it to crash due to double-free/delete potential.
  * Fixed the automatic aggregation of new Graph client nodes
    that are split as either input or output only (ie. system,
    terminal, physical or otherwise non-duplex nodes).
  * Added View/Zoom Range mode option to Graph tool.
  version 0.5.1
  * Half a decade later, recent new custom entries may now get
    removed from Session Infra-client list.
  * Some rather old, better said "Cambric explosion era", user
    preference options have been ditched altogether: Display /
    Time Format; Display / Shiny glass light effect; Display /
    Connections/Draw connections and patchbay lines as Bezier
    curves; Misc/Configure as temporary server.
  * A brand new and way long overdue connections Graph widget
    is finally introduced, only to be accessible through the
    context menu at this time.
  * Extended multi-selection is now supported on all Connections
    client/port lists, allowing for multiple (dis)connections at
    once.
  * Disable singleton/unique application instance setup logic
    when the display server platform is not X11.
  * A little hardening on the configure (autoconf) macro side.
  version 0.5.0
  * Current preset is always taken into account if ever changes
    while the Setup dialog is hidden (eg. via context menu).
  * Desktop entry specification file is now finally independent
    from build/configure template chains.
  * Updated target path for freedesktop.org's AppStream metainfo
    file (formerly AppData).
  version 0.4.5
  * On some desktop-shells, the system tray icon blinking on
    XRUN ocurrences, have been found responsible to excessive
    CPU usage, an "eye-candy" effect which is now optional as
    far as Setup/Display/Blink server mode indicator goes.
  * Added French man page (by Olivier Humbert, thanks).
  * Make builds reproducible byte for byte, by getting rid of
    the configure build date and time stamps.
  version 0.4.4
  * Fixed an early crash when the singleton/unique application
    instance setup option is turned off.
  * Almost complete overhaul on the configure script command
    line options, wrt. installation directories specification,
    eg. --prefix, --bindir, --libdir, --datadir and --mandir.
* Sun Oct  9 2016 virtuousfox@gmail.com
- update to version 0.4.3
  * Fix build error caused by variable length array.
  * Fix some tooltip spelling (patch by JaromÃ­r MikeÅ¡, thanks).
  * Translation (not) fix for the default server name "(default)".
  * Old "Start minimized to system tray" option returns to setup.
  * Dropped the --enable-qt5 from configure as found redundant given
    that's the build default anyway (suggestion by Guido Scholz,
    while for Qtractor, thanks).
  * Late again French (fr) translation update
    (by Olivier Humbert aka. trebmuh, thanks).
- removal of qjackctl-gcc6.patch and qjackctl-return_tray_minimization.patch
  due to their inclusion into this release
* Fri Sep  2 2016 virtuousfox@gmail.com
- replacement of qjackctl-remove_absolute_path_from_exec_in_desktop-file.patch
  and qjackctl-remove_build_timestamps.patch with simple sed directives
- qjackctl-gcc6.patch: backport of the patch to build with gcc6
- qjackctl-return_tray_minimization.patch: backport of the patch to
  return "start minimized" option
* Fri Sep  2 2016 virtuousfox@gmail.com
- update to version 0.4.2 from version 0.4.0
- changes between versions 0.4.1 and 0.4.2
  * Added a brand new "Enable JACK D-BUS interface" option, split
    from the old common "Enable D-BUS interface" setup option which
    now refers to its own self D-BUS interface exclusively.
  * Dropped old "Start minimized to system tray" option from setup.
  * Add double-click action (toggle start/stop) to systray (a pull
    request by Joel Moberg, thanks).
  * Added application keywords to freedesktop.org's AppData.
  * System-tray icon context menu has been fixed/hacked to show up
    again on Plasma 5 (aka. KDE5) notification status area.
  * Switched column entries in the unified interface device combo-
    box to make it work for macosx/coreaudio again.
  * Blind fix to a FTBFS on macosx/coreaudio platforms, a leftover
    from the unified interface device selection combo-box inception,
    almost two years ago.
  * Prevent x11extras module from use on non-X11/Unix plaforms.
  * Late French (fr) translation update (by Olivier Humbert, thanks).
- changes between versions 0.4.0 and 0.4.1
  * Probing portaudio audio device in a separate thread (by Kjetil
    Matheussen, thanks).
  * Messages standard output capture has been improved again, now
    in both ways a non-blocking pipe may get.
  * Regression fix for invalid system-tray icon dimensions reported
    by some desktop environment frameworks.
  * New hi-res application icon (by Uttrup Renzel, Max Christian
    Pohle, thanks).
  * System tray icon red background now blinks when a XRUN occurs.
  * Desktop environment session shutdown/logout management has been
    also adapted to Qt5 framework.
  * Single/unique application instance control adapted to Qt5/X11.
  * Prefer Qt5 over Qt4 by default with configure script.
  * Overrideable tooltips with latency info (re. Connections JACK
    client/ports: patch by Xavier Mendez, thanks).
  * Complete rewrite of Qt4 vs. Qt5 configure builds.
  * French (fr) translation update (by Olivier Humbert, thanks).
* Tue Aug 11 2015 stephan.barth@suse.com
- update to version 0.4.0, including version 0.3.13
  Important changes from upstream for version 0.4.0:
  - Most advanced Setup/Settings are moved into new Setup/Advanced settings
    tab; limit range for the real-time priority setting, now having 6 as
    absolute minimum valid value (after patches by Robin Gareus, thanks).
  - A new top-level widget window geometry state save and restore sub-routine
    is now in effect (EXPERIMENTAL)
  - Delayed geometry setup for widget windows upon startup has been deprecated
    and scrapped altogether.
  - Setup/settings dialog tab is going into some layout changes; also got rid
    of old patchbay auto-refresh timer cruft, which was previously
    hidden/disabled.
  - New socket names are now automatically inferred from selected client names
    while on the Patchbay widget, Socket dialog.
  Important changes from upstream for version 0.3.13:
  - Added application description as freedesktop.org's AppData.
  - Setup dialog form is now modeless.
  - Introducing brand new active patchbay reset/disconnect-all user preference
    option.
  - Current highlighted client/port connections are now drawn with thicker
    connector lines.
  - New user preference option on whether to show the nagging 'program will
    keep running in the system tray' message, on main window close.
  - Connections lines now drawn with anti-aliasing; connections splitter
    handles width is now reduced.
  - Drop missing or non-existent patchbay definition files from the most
    recent used list.
* Fri Mar 13 2015 p.drouand@gmail.com
- Update to version 0.3.12
  * JACK client/port pretty-name (metadata) support is being introduced
    and seamlessly integrated with old Connections client/port aliases
    editing (rename) (EXPERIMENTAL)
  * Application close confirm warning is now raising the main window
    as visible and active for due top level display, especially
    applicable when minimized to the system tray.
  * Messages standard output capture has been slightly improved as
    for non-blocking i/o, whenever available.
  * Translations install directory change.
  * Allow the build system to include an user specified LDFLAGS.
  * Missing input/output-latency parameter settings now settled for
    the D-BUS controlled JACK server and firewire back-end driver.
- Recommend the translations subpackage
* Thu Mar  6 2014 stephan.barth@suse.com
- qjackctl-remove_absolute_path_from_exec_in_desktop-file.patch:
  This patch removes the absolute path of the qjackctl binary from the desktop
  file, that is in %%{_datadir}/applications/%%{name}.desktop
  (This was not mentioned in the previous submission)
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 0.3.11:
  * interface device selection is now unified, by moving the old '>' pop-up
    menu into the customized combo-box drop-down list showing all available
    card/device names and descriptions
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 0.3.10:
  * session infra-client management finally being added
  * transport tempo (BPM) precision display fixed to 4 digits
  * color-candy (dang old ANSI terminal?) escape sequences are
    now silently stripped from jackdbus messages captured log
  * list ALSA device card id. string instead of device number,
    while on setup dialog
  * Japanese (ja) translation added
* Fri May 18 2012 pascal.bleser@opensuse.org
- update to 0.3.9:
  * killing D-BUS controlled JACK server is now made optional, cf.
    Setup/Misc/Stop JACK audio server on application exit
  * a new so called "Server Suffix" parameter option appears to rescue on the
    situations where QjackCtl falls short on extra, exquisite and/or esoteric
    command line options eg. (net)jack1/2 differences.
  * fixed D-Bus Input/Output device parameter settings, filled when either
    interface is selected for Capture/Playback only
  * main window is now brought to front and (re)activated when clicking on the
    system tray icon instead of just hiding it
  * add current xrun count to the system tray icon tooltip, if not zero
- added portaudio support
- revamped spec file
- moved translations to -lang package
* Sun Aug  7 2011 mseben@gmail.com
- update to 0.3.8:
  - Debugging stacktrace now applies to all working threads.
  - Session "Save" button now a drop-down menu, replacing the
    session save type combo-box/drop-down list selection. Also,
    an early session directory versioning/numbering scheme is
    now in place, although optional.
  - Probable fix to debian bug report #624198 - segfault when
    pressing the stop button (by Grant Adrian Diffey, after a
    patch from Adrian Knoth, thanks).
  - Desktop environment session shutdown (eg. logout) is now
    tapped for graceful application exit, even though the main
    window is active (visible) and minimizing to system tray
    is enabled. Both were causing first shutdown/logout attempt
    to abort. Not anymore, hopefully ;).
  - Make sure all activated patchbay definition files are in
    their complete and absolute directory path forms.
  - Connections refresh button now does an immediate and true
    reconstruction of all clients and their respective ports
    and connections, unconditionally.
  - Command line server start option (-s, --start) is now made
    independent from configuration setup option (cf. Setup/Misc
    /Start JACK audio server on application startup).
  - Now handling cable socket types properly to let patchbay
    definitions work correctly, whenever having sockets with
    the very same literal name (twisted from patch #3183467,
    by Karsten, thanks;).
  - Abrupt focus behavior when any of the keyboard modifiers
    (Shift, Ctrl, Alt, Caps Lock) is hit while on Connections
    client/port aliases editing (rename) has been fixed.
  - Russian (ru) translation updated (by Alexandre Prokoudine).
  - Added include "errno.h" alegedly missing for BSD style
    systems (applying patch for bug #3126091).
* Wed Dec  1 2010 mseben@gmail.com
- updated to 0.3.7:
  - Session widget has session save type preserved as well.
  - Connections and the new Messages/Status widgets now have
    their last open tab preserved across program run-cycles.
  - Connections and Patchbay widgets have been finally given
    up on an old feature request: an Expand All items button.
  - The Messages and Status widgets were merged into one,
    giving space to the new Session wigdet
  - libX11 is now being added explicitly to the build link
    phase
  - Input/Output latency options were missing but now finally
    enabled for the firewire back-end.
  - General standard dialog buttons layout is now in place.
  - Avoid pre-loading a stalled patchbay definition filename
    and its nagging error on startup (fixes bug #3017078).
  - Client connection retrial logic scrapped. Being a leftover
    from early ages, when machines were slower and JACK server
    startup times were longer... now, if it can't connect first
    time as client, it will tear down the server whether it's
    starting up still or not at all. (cf. Setup/Settings/Start
    Delay for the rescue).
  - Server name is finally part of the server settings presets,
    thanks to Fons Adriaensen for the heads-up.
  - As a workaround regarding issues switching jack2's backends,
    Robin Gareus sends us yet another D-Bus metho slot: "preset",
    (dbus-send --system / org.rncbc.qjackctl.preset string:PRESET).
    Thanks again.
  - Another D-Bus interface slot makes it through implementation:
    "quit" (eg. usage: dbus-send --system / org.rncbc.qjackctl.quit).
    Besides, there's also these new JACK session management actions
    which were being overlooked as well: "load", "save", "savequit"
    and "savetemplate" are also available as D-Bus method slots.
  - Make sure that Patchbay socket names are unique when adding
    or copying, fixing previous patch by Dominic Sacre.
  - JACK version is now being shown on the About box (jack2).
  - Slight Connections widget behavioral change: (dis)connecting a
    client (from) to one single port, (dis)connections will be
    applied in sequence from (to) all client output ports to (from)
    as many input ports there are in below, one by one (satisfying
    a 5 year old request from Yann Orlarey, thanks:).
  - JACK session support is being introduced.
  - Ignore first XRUN occurrence option dropped from statistics.
  - Initial widget geometry and visibility persistence logic has
    been slightly revised as much to avoid crash failures due to
    wrong main widget hidden state.
  - Double-quotes are now being added to device names which include
    blank characters and were rendering invalid all command line
    invocation of the classic JACK server (eg. specially due for
    Portaudio device names on Windows).
  - Transport play (rolling) status is now being guarded to avoid
    backfiring from extraneous transport state changes.
  - General source tree layout and build configuration change.
  - Italian (it) translation added (by Sergio Atzori).
  - Post-shutdown script invocation logic slightly refactored in
    attempt to enforce its execution on application quit.
- deprecated translation-folder.diff
* Wed Apr  7 2010 davejplater@gmail.com
- Updated to 0.3.6: now has full D-Busification!
- Fix patch qjackctl-translation-folder.diff
- Make sure socket names are unique on each side of the Patchbay
- A bunch of primitive D-Bus interface slots have been added,
- Patchbay snapshot now tolerates JACK client port strings that
  have more than one semi-colon in it.
- Most modal message dialog boxes (eg. critical errors) are now
  replaced by system tray icon bubble messages where available
- Comply with jackd >= 0.118.0 which now runs in real-time mode by
  default; use of -R is now deprecated from the jackd command line
  interface options; use -r to run in non-real-time-scheduling.
- A man page has beed added.
- Got rid of a pretty old and never really useful "jackd-realtime"
  server path option.
- D-Bus support, as provided by org.jackaudio.service aka jackdbus,
  is now being introduced and used wherever available and whenever
  enabled.
- Server name command line option added (-n, --server-name).
- Single application instance restriction option added (X11).
- Setup for the netjack (slave) "net" driver has now sample-rate
  and frames per buffer (period size) settings disabled and/or
  ignored, as those are pretty much auto-detected by default;
  also, a new "netone" backend driver option has been introduced
- Czech (cs) translation added (by Pavel Fric).
- Fixed glitch on configure portaudio support, specially when the
  library is not detected as available. See changelog for more.
* Mon Nov 16 2009 mseben@novell.com
- updated to 0.3.5:
  * Late support for UTF-8 encoded client/port names.
  * Allow only one single patchbay connection to or from an
    exclusive socket.
  * Automatic crash-dump reports, debugger stack-traces (gdb),
    back-traces, whatever, are being introduced as a brand new configure
    option (--enable-stacktrace) and default enabled on debug build
    targets (--enable-debug).
  * Probable fix on the audio connections with regard to client/port
    (re)name changes (an ancient bug reported by Fons Adriaensen).
  * Portaudio device selector is now available (after a patch
    handed by Torben Hohn and Stephane Letz).
  * A couple of primitive D-Bus interface slots have been introduced,
    giving the option to start/stop the jackd server from the system
    bus eg. via dbus-send --system / org.rncbc.qjackctl.start (.stop),
    (a nice addition supplied by Robin Gareus, thanks).
  * New command line option (-a, --active-patchbay=path) to specify and
    activate a given patchbay definition file (a simple patch sent by
    John Schneiderman, thanks).
  * Added one significant digit to DSP Load percentage status display.
  * Tentative support for netjack (slave) by adding the "net" driver to
    the existing backend driver options on the Setup/Settings section.
  * Converted obsolete QMessageBox forms to standard buttons.
  * New patchbay snapshot now raises the dirty flag and allows for
    the immediate salvage of patchbay definition profile.
  * Conditional build for JACK port aliases support (JACK >= 0.109.2).
  * Alternate icon sizes other than default 16x16, are now effective to
    the Connections widget (Setup/Dislay/Connections Window/Icon size).
* Mon Aug 31 2009 mseben@suse.cz
- added jack to Requires section
* Tue Dec  9 2008 tiwai@suse.de
- updated to version 0.3.4:
  * Translations in-package
  * The rewrite of old patchbay snapshot feature
  * On Setup/Settings/Parameters dialog, all device selection
    options are now reset to default when disabled interactively.
  * Grayed/disabled palette color group fix for dark color themes.
  * Qt Software logo update.
  * Fait-divers: desktop menu file touched to openSUSE conventions.
  * ALSA PCM devices now only listed/enumerated iif strictly
    compliant with the audio mode criteria
  * JACK client/port aliases may now be displayed as a global user
    option (see Setup/Display/Connections/JACK client/port aliases).
  * Lighten up the connections line and highlight colors, as seen
    to fit best on some darker background themes.
  * Patchbay snapshot fixed to differentiate socket clients
    according to its type (Audio, MIDI or ALSA-Seq).
  * JACK_DEFAULT_SERVER environment variable is now appended to the
    X11 unique application identifier, allowing for having multiple
    instances each controlling its own JACK server.
  * Due to some trouble with newer Qt >= 4.4 applications regarding
    font size configuration, a new global user option is now
    available to the rescue: Setup/Misc/Defaults/Base font size
- moved translation path from locale directory to its own one,
  as build doesn't accept it (yet).
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 0.3.3:
  * load Qt's own translation support and get rid of the ever
    warning startup message
  * Messages file logging makes its first long overdue appearance
  * Only one application instance is now allowed
  * Full JACK MIDI support sneaks into the patchbay
  * Sun driver support
  * Delay window positioning at startup option is now being
    disabled
  * Cosmetic fix for apperance
* Fri Dec 21 2007 tiwai@suse.de
- updated to version 0.3.2:
  * Patchbay port matching has been slightly extended
  * Start option from Setup/Misc/Start
  * Regression from QSystemTrayIcon (Qt4 >= 4.2) implementation
  * Some portaudio backend settings are now being enabled
  * Server mode display blinking (RT indicator) is now an option
  * Tool/child windows position and size preservation fixed.
  * The connections/patchbay auto-refresh option has been removed
  * Messages line limit was not being checked, now honored.
  * Patchbay snapshot got its socket and port ordering back.
  * ALSA Sequencer support is now an optional feature on setup
  * Get configure to try and detect the correct qmake location
  * The connections widget is now being properly refreshed
  * The xrun count stats can now be reset simply by middle clicking
    on the systray icon or the main window's display area
  * An improved version of the "shiny" background image was issued
  * A warning is now being issued, asking whether one wants to
    remove a corresponding Patchbay connection, etc
  * The infamous "Keep child windows always on top" global option
    is now supposed to behave a little better
  * Input/Output Channel setting is allowed to be greater than 32
* Thu Jul 19 2007 tiwai@suse.de
- updated to version 0.3.1a:
  * system-tray icon tooltip shows the current DSP load
  * fixed Connections/Patchbay item tooltip crash bug
  * use QSystemTrayIcon class facility if available
  * refactoring QProcess class usage
  * A new eye-candy bit has sneaked in
  * Combo-box setup history has been corrected on restore
* Wed Jul 11 2007 tiwai@suse.de
- updated to version 0.3.0:
  * Qt4 migration
* Tue Jul  3 2007 tiwai@suse.de
- updated to version 0.2.23:
  * JACK MIDI support is now being introduced
  * Application icon is now installed to ${prefix}/share/pixmaps
  * Invalidation of the JACK client handle is now forced right on
    jack_shutdown notification
  * Default font option names were adjusted to "Sans Serif" and
    "Monospace"
  * The "keep child windows always on top" option is not set as
    default anymore
  * Autoconf (configure) scripting gets an update.
* Mon Apr  2 2007 tiwai@suse.de
- updated to version 0.2.22:
  * Fixed default settings for the freebob backend (JACK >=
    0.103.0).
  * CPU Load status label now says correctly DSP Load.
  * The most recently used patchbay definitions can now be
    correctly selected in round-robin fashion from its drop-down
    list widget.
  * Avoid mixing JACK MIDI ports with regular audio ports on the
    Connections and Patchbay widgets; strictly list only audio
    ports.
  * Added 192k sample rate to setup settings drop down list (as
    kindly reminded by Klaus Zimmermann, thanks).
  * Most top-level widgets were missing the normal-widget flag,
    which were causing some sticky size behavior on some window
    managers.
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 0.2.21:
  * GPL address update
  * All window captions can now be set smaller as tool-widgets
  * The main window button text labels are now optional
  * Increased the default maximum number of ports setting from 128 to 256.
  * Initial freebob backend driver support
  * Quit the whole app when closing the main window
  * Rewind, Play and Pause transport commands are on main pop-up menu
  * Call post-shutdown script when using the Stop button
  * The main window buttons display are now optional
  * Added configure support for x86_64 libraries
* Mon May 15 2006 tiwai@suse.de
- updated to version 0.2.20.
  * new cmdline option for server path
  * improved patchbay dialog
  * improved XRUN callback notification
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 tiwai@suse.de
- updated to 0.2.19a.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Oct 12 2005 tiwai@suse.de
- fix for qt3.3.5 (remove invalid includehints)
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 0.2.18.
* Wed Feb  9 2005 tiwai@suse.de
- updated to version 0.2.15a.
* Tue Feb  8 2005 tiwai@suse.de
- updated to version 0.2.15.
* Mon Jan 24 2005 tiwai@suse.de
- updated to version 0.2.14.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.2.13.
* Fri Jan  7 2005 adrian@suse.de
- fix build, qmake isn't in default $PATH anymore
* Wed Sep 22 2004 mskibbe@suse.de
- change specfile (suse_update_desktop_file)
* Mon Sep  6 2004 tiwai@suse.de
- updated to version 0.2.10.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.2.9.
* Mon Jun 14 2004 mana@suse.de
- update to version 0.2.8
* Mon Mar  1 2004 tiwai@suse.de
- updated to version 0.2.6.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 0.2.5.
- build as non-root.
* Mon Jan 19 2004 tiwai@suse.de
- updated to version 0.2.3a.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 0.1.2.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Tue Sep  2 2003 tiwai@suse.de
- changed the default configuration for suse distro.
* Mon Sep  1 2003 tiwai@suse.de
- merge 0.0.4 updates.
  minor bugfixes only.
* Sun Aug 17 2003 adrian@suse.de
- justify Category
* Thu Aug 14 2003 tiwai@suse.de
- initial version: 0.0.3.
